@@ -7,6 +7,7 @@ use Carp;
 use CPANPLUS::Backend;
 use CPANPLUS::Configure;
 use CPANPLUS::Error;
+use CPANPLUS::Internals::Constants;
 use POSIX qw( O_CREAT O_RDWR O_RDONLY );         # for SDBM_File
 use SDBM_File;
 use File::Fetch;
@@ -34,7 +35,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT    = ( @{ $EXPORT_TAGS{'default'} } );
 
-$VERSION = '0.33_04';
+$VERSION = '0.43_01';
 
 {
   my %Checked;
@@ -44,7 +45,7 @@ $VERSION = '0.33_04';
 sub _connect_db {
   my $self = shift;
   return if $TiedObj;
-  my $filename = catfile( CPANPLUS::Internals::Utils->_home_dir(), '.cpanplus', DATABASE_FILE );
+  my $filename = catfile( $self->{conf}->get_conf('base'), DATABASE_FILE );
   $TiedObj = tie %Checked, 'SDBM_File', $filename, O_CREAT|O_RDWR, 0644;
   $self->{checked} = \%Checked;
 }
@@ -59,22 +60,25 @@ sub _disconnect_db {
 
 sub new {
   my $package = shift;
+  my $nconf = shift if ref $_[0] and $_[0]->isa('CPANPLUS::Configure');
 
   $ENV{AUTOMATED_TESTING} = 1;
   $ENV{PERL_MM_USE_DEFAULT} = 1; # despite verbose setting
 
-  my $conf = CPANPLUS::Configure->new();
+  my $conf = $nconf || CPANPLUS::Configure->new();
 
   # Override configure settings
   $conf->set_conf( prereqs => 2 ); # force to ask callback
   $conf->set_conf( skiptest => 0 ); 
+  $conf->set_conf( no_update => 1 )
+    if glob( catfile( $conf->get_conf('base'), $conf->_get_source('stored') .'*'. STORABLE_EXT, ) );
   $conf->set_conf( dist_type => 'CPANPLUS::Dist::YACSmoke' ); # this is where the magic happens.
   $conf->set_conf( cpantest => 'dont_cc' ); # Yes, we want to report test results. But not CC
   $conf->set_conf( verbose => 1 ); # set verbosity to true.
 
   unless ( defined $ENV{MAILDOMAIN} ) {
      my $hostpart = ( split /\@/, ( $conf->get_conf( 'email' ) || 'smoker@cpantesters.org' ) )[1];
-     $ENV{MAILDOMAIN} = $hostpart eq 'cpan.org' ? 'cpantesters.org' : $hostpart;
+     $ENV{MAILDOMAIN} = $hostpart =~ /^(cpan\.org|gmail\.com)$/i ? 'cpantesters.org' : $hostpart;
   }
 
   if ( $^V gt v5.9.5 ) {
@@ -88,7 +92,7 @@ sub new {
   my $cb   = CPANPLUS::Backend->new($conf);
 
   my $exclude_dists;
-  my $config_file = catfile( CPANPLUS::Internals::Utils->_home_dir(), '.cpanplus', CONFIG_FILE );
+  my $config_file = catfile( $conf->get_conf('base'), CONFIG_FILE );
   if ( -r $config_file ) {
      my $cfg = Config::IniFiles->new(-file => $config_file);
      my @list = $cfg->val( 'CONFIG', 'exclude_dists' );
@@ -532,6 +536,21 @@ The object interface is created normally through the test() or mark() functions
 
 =head1 ENVIRONMENT VARIABLES
 
+The following environment variables affect the operation of this module:
+
+=over
+
+=item C<PERL5_YACSMOKE_BASE>
+
+Loaded into L<CPANPLUS> by L<CPANPLUS::Config::YACSmoke>, sets the basedir where L<CPANPLUS> and
+CPANPLUS::YACSmoke related modules find the C<.cpanplus> directory for their settings
+
+  export PERL5_YACSMOKE_BASE=/home/moo/perls/conf/perl-5.8.9/
+
+Would set the base dir to C</home/moo/perls/conf/perl-5.8.9/.cpanplus/>
+
+=back
+
 Several environment variables get set by the module:
 
 =over
@@ -545,10 +564,6 @@ Set to 1 to indicate that we are currently running in an automated testing envir
 Set to 1 MakeMaker and Module::Build's prompt functions will always return the default 
 without waiting for user input.
 
-=item C<PERL5_CPANPLUS_VERBOSE>
-
-Set to 1 so L<CPANPLUS> will run in C<verbose> mode.
-
 =item C<MAILDOMAIN>
 
 L<Test::Reporter> uses this. YACSmoke will set this if it isn't already set. It will try to determine
@@ -567,7 +582,7 @@ Contributions and patience from Jos Boumans the L<CPANPLUS> guy!
 
 =head1 LICENSE
 
-Copyright C<(c)> Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
+Copyright E<copy> Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
 
 This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
 
@@ -577,6 +592,8 @@ L<CPANPLUS>
 
 L<CPANPLUS::Dist::YACSmoke>
 
+L<CPANPLUS::Config::YACSmoke>
+
 L<CPAN::YACSmoke>
 
 L<Test::Reporter>
